@@ -1,14 +1,13 @@
 use mit_commit::CommitMessage;
 use regex::Regex;
 
-use crate::console::exit::Code;
-use crate::lints::lib::Problem;
+use crate::{console::exit::Code, lints::lib::Problem};
 
 pub(crate) const CONFIG: &str = "jira-issue-key-missing";
 const HELP_MESSAGE: &str = indoc::indoc!(
     "
     It's important to add the issue key because it allows us to link code back to the motivations \
-    for doing it, and in some cases provide an audit trail for compliance purposes.
+     for doing it, and in some cases provide an audit trail for compliance purposes.
 
     You can fix this by adding a key like `JRA-123` to the commit message"
 );
